@@ -19,9 +19,11 @@ make check
 
 lcov -d ./ -c -o coverage_all.info
 #lcov --extract coverage_all.info $EXTRACT_ARGS --output-file coverage.info
-lcov --remove coverage_all.info "*/tests/*" "*/usr/include*" "*build/src*" --output-file coverage.info
+lcov --remove coverage_all.info "*/filedrag/*" "*/dbus/*" "*/tests/*" "*/usr/include*" "*build/src*" --output-file coverage.info
 cd ..
 genhtml -o $REPORT_DIR $BUILD_DIR/coverage.info
 
-rm -rf $BUILD_DIR
-rm -rf ../$BUILD_DIR
+#rm -rf $BUILD_DIR
+#rm -rf ../$BUILD_DIR
+
+test -e ./build/asan.log* && mv ./build/asan.log* ./build/asan_dtkgui.log || touch ./build/asan_dtkgui.log
